@@ -261,8 +261,9 @@ class ReleaseWizard(ReleaseWizardBA):
     def importChangeLog(self):
         self.changeLogPushButton.setOn(False)
         self.changeLogPushButton.setDown(False)
+
         fn = QFileDialog.getOpenFileName(self.change_log_path or self.release_notes_path,
-                                         None,
+                                         "",
                                          self,
                                          "Import Change Log",
                                          "Import Change Log")
@@ -278,7 +279,7 @@ class ReleaseWizard(ReleaseWizardBA):
         self.releaseNotesPushButton.setDown(False)
 
         fn = QFileDialog.getOpenFileName(self.release_notes_path or self.change_log_path,
-                                         None,
+                                         "",
                                          self,
                                          "Import Release Notes",
                                          "Import Release Notes")
@@ -363,8 +364,9 @@ class ReleaseWizard(ReleaseWizardBA):
             part = part.lower()
             guess = CPU_GUESS.get(part)
             if guess: break
-        debug("guess: %s cpu is: %s", filename, guess)
-        return guess
+        
+        debug("guess: %s cpu is: %s", filename, guess or "Any")
+        return guess or "Any"
 
     
 
@@ -397,7 +399,7 @@ class ReleaseWizard(ReleaseWizardBA):
         rownum = self.releaseFilesTable.numRows()
         for i in range(rownum):
             cpuCombo = self.releaseFilesTable.item(i, COL_CPU)
-            cpuCombo.setCurrentItem(name)
+            cpuCombo.setCurrentItem(name or 0) 
         if self.__validateFiles(rownum):
             self.setNextEnabled(self.page(WIZARD_PAGE_FILE_SELECTION), True)
             
@@ -405,7 +407,7 @@ class ReleaseWizard(ReleaseWizardBA):
     def addFiles(self):
         self.addFilesPushButton.setOn(False)
         self.addFilesPushButton.setDown(False)
-        files = QFileDialog.getOpenFileNames(None,
+        files = QFileDialog.getOpenFileNames("",
                                              self.release_files_path,
                                              self,
                                              "Add Files",
@@ -422,7 +424,7 @@ class ReleaseWizard(ReleaseWizardBA):
             self.__addFile(filename,
                            self.__guessProcessorType(filename),
                            self.__guessFileType(filename),
-                           fstr)                           
+                           fstr)
 
         self.__resizeBasenameColumn()
         if self.releaseFilesTable.numRows() > 0:
@@ -442,6 +444,7 @@ class ReleaseWizard(ReleaseWizardBA):
         cpuData = self.__getProcessorComboData()
         cpuCombo = QComboTableItem(self.releaseFilesTable,
                                    cpuData)
+
         cpuCombo.setCurrentItem(cpu)
         
         self.releaseFilesTable.setItem(rownum, COL_CPU, cpuCombo)
@@ -449,7 +452,7 @@ class ReleaseWizard(ReleaseWizardBA):
         fileTypeData = self.__getFileTypeComboData()
         fileTypeCombo = QComboTableItem(self.releaseFilesTable,
                                         fileTypeData)
-        fileTypeCombo.setCurrentItem(filetype)
+        fileTypeCombo.setCurrentItem(filetype or 0)
         self.releaseFilesTable.setItem(rownum, COL_FILE_TYPE, fileTypeCombo)
             
         self.releaseFilesTable.setText(rownum, COL_FILENAME, fullpath)
