@@ -17,6 +17,7 @@ from messageQueue import mainMessageQueue, progressMessageQueue, ftpProgressQueu
 import os, sys
 from ftp import FTP_
 import time
+from constants import SF_RESPONSE_CHUNK_SIZE
 
 debug = logging.getLogger("sfcomm").debug
 error = logging.getLogger("sfcomm").error
@@ -56,8 +57,32 @@ class SFComm:
             pass
         
 
-    def fetch_url(self, url, post_encoded=None, queue=progressMessageQueue, addl_headers=None):
+    def fetch_url(self,
+                  url,
+                  post_encoded=None,
+                  queue=progressMessageQueue,
+                  addl_headers=None,
+                  ok_status=None):
+        #
+        # parameters:
+        # url: url to retrieve
+        # post_encoded: the encoded query string sent to SF
+        # queue: the python Queue that status information will be sent to
+        # addl_headers: any additional headers that need to be passed to SF
+        # ok_status: a string as described below.
+        #
+        # returns a tuple containing the data returned from SF and the status.
+        #
+        # If ok_status is provided, the status returned is True if the
+        # string ok_status is found, False otherwise. additionally, the data
+        # returned will be truncated as soon as ok_status is found.
+        #
+        # If ok_status is None, status is always True and data will not be truncated
+        #
+        # return tuple form: (data, status)
+        #
         data = ""
+        ok = True
         try:
             debug("Fetching: %s", url)
             if post_encoded:
@@ -75,12 +100,34 @@ class SFComm:
                 
             r = opener.open(url, post_encoded)
 #            cj.save(self.cookie_file, True)
-            data = r.read()
+            if not ok_status: 
+                # fetch entire response
+                data = r.read()
+            else:
+                # chunk through the response... searching for ok_status
+                # if found, return true, otherwise false
+                while True:
+                    chunk = r.read(SF_RESPONSE_CHUNK_SIZE)
+                    
+                    if not chunk:
+                        ok = False 
+                        break
+                    data = "%s%s" % (data, chunk)
+                    debug("fetched: %d bytes", len(data))
+
+                    if data.find(ok_status) != -1:
+                        break
+                if ok:
+                    debug("found '%s' in response", ok_status)
+                else:
+                    debug("did not find '%s' in response", ok_status)
+
+            r.close()
             debug("Done")
             #debug("length: %ld  -  url: %s", len(data), url)
         except Exception, e:
             print e
-        return data
+        return data, ok
 
 
 
@@ -137,19 +184,27 @@ class SFComm:
     def get_packages(self, group_id):
         url = "%s=%s" % (EDIT_PACKAGE_BASE_URL, group_id)
         packages = set()
-        data = self.fetch_url(url, queue=mainMessageQueue)
+        data = self.fetch_url(url, queue=mainMessageQueue)[0]
         debug("data: %s", data)
         #forms = PACKAGE_FORMS.findall(data)[:-1]  # -1 = New package name
             
         fullaccess = "True"
         package_tuples = PACKAGES_FULL_ACCESS.findall(data)
-        if not package_tuples:
+        if not package_tuples and self.can_create_releases(group_id):           
+            # access is limited
             fullaccess = "False"
+            url = "%s=%s" % (GET_PACKAGES, group_id)
+            data = self.fetch_url(url, queue=mainMessageQueue)[0]
+            debug("data: %s", data)
             package_tuples = PACKAGES_LIMITED_ACCESS.findall(data)
         for package_tuple in package_tuples:
+            try:
+                status = package_tuple[2]
+            except:
+                status = 'Active'
             packages.add(PackageVO(package_tuple[1],
                                    package_tuple[0],
-                                   package_tuple[2],
+                                   status,
                                    fullaccess))
         debug("Found %d packages for group_id %s", len(packages), group_id)
         return packages
@@ -161,11 +216,23 @@ class SFComm:
                 'func': "add_package",
                 "package_name": package_name,
                 'submit': "Create This Package"}
-        data = self.fetch_url(url, urlencode(form), mainMessageQueue)
-        if data.find("Added Package") != -1: return 1
-        else: return 0
+        data, ok  = self.fetch_url(url, 
+                                   urlencode(form), 
+                                   mainMessageQueue,
+                                   ok_status="Added Package")
+        return ok
 
 
+    def can_create_releases(self, group_id):
+        url = "%s?group_id=%s" % (NEW_RELEASE_URL,
+                                  group_id)
+        data, ok = self.fetch_url(url, ok_status=">Permission denied<")
+        if ok:
+            mainMessageQueue.put("You do not have the proper permissions")
+            return False
+        else: return True
+        
+
     def add_release(self, group_id, package_id, name):
         url = "%s?package_id=%s&group_id=%s" % (NEW_RELEASE_URL,
                                                 package_id,
@@ -176,7 +243,7 @@ class SFComm:
                 'newrelease': 'yes',
                 'submit': 'Create This Release'}
 
-        data = self.fetch_url(url, urlencode(form))
+        data = self.fetch_url(url, urlencode(form))[0]
         #print url
         m = GET_RELEASE_ID.search(data)
         if m:
@@ -196,7 +263,7 @@ class SFComm:
                                                 group_id,
                                                 package_id)
         
-        data = self.fetch_url(url, queue=mainMessageQueue)
+        data = self.fetch_url(url, queue=mainMessageQueue)[0]
 
         matches = GET_RELEASES.findall(data)
         return matches
@@ -209,7 +276,7 @@ class SFComm:
                                                               package_id,
                                                               release_id)
         
-        data = self.fetch_url(url, queue=mainMessageQueue)
+        data = self.fetch_url(url, queue=mainMessageQueue)[0]
         idx = data.find("Edit Existing Release")
         if idx == -1: return None
 
@@ -256,7 +323,7 @@ class SFComm:
                 'package_name': package_name,
                 'status_id': status_id,
                 'submit': 'Update'}
-        data = self.fetch_url(url, urlencode(form), mainMessageQueue)
+        data = self.fetch_url(url, urlencode(form), mainMessageQueue)[0]
 
         if data.find("Sorry - you cannot hide a package that contains active releases") != -1:
             result = -1
@@ -277,7 +344,7 @@ class SFComm:
                 'newrelease': 'yes',
                 'submit': 'Create This Release'}
 
-        data = self.fetch_url(url, urlencode(form))
+        data = self.fetch_url(url, urlencode(form))[0]
         #print url
         m = GET_RELEASE_ID.search(data)
         if m:
@@ -315,11 +382,12 @@ class SFComm:
                 'preformatted': '1',
                 'submit': 'Submit/Refresh'
                 }
-        data = self.fetch_url(url,
-                              urlencode(form))
-
-        if data.find("Data Saved") != -1: return True
-        else: return False
+        ok = self.fetch_url(url,
+                            urlencode(form),
+                            ok_status="Data Saved")[1]
+        return ok
+        #if data.find("Data Saved") != -1: return True
+        #else: return False
 
 
 
@@ -335,13 +403,14 @@ class SFComm:
             filename = fileVO.getFilename()
             enc += "&file_list%s=%s" % (quote_plus("[]"), quote_plus(filename))
             
-        data = self.fetch_url(url, enc)
+        data, ok = self.fetch_url(url, enc, ok_status="File(s) Added")
 
         warnings = GET_FILE_WARNINGS.findall(data)
         debug("step2 warnings: %s", str(warnings))
 
-        if data.find("File(s) Added") != -1: ok = True
-        else:
+#        if data.find("File(s) Added") != -1: ok = True
+#        else:
+        if not ok:
             error("Error selecting %s for inclusion", filename)
             #debug("dumping data: %s", data)  # remove me...
             ok = False
@@ -371,9 +440,9 @@ class SFComm:
             form['type_id'] = fileVO.getFileTypeId()
             try:
                 form['file_id'] = lookup_dict[fileVO.getFilename()]
-                data = self.fetch_url(url, urlencode(form))
-                if data.find("File Updated") != -1: ok &= True
-                else: ok &= False
+                ok &= self.fetch_url(url, urlencode(form), ok_status="File Updated")[1]
+#                if data.find("File Updated") != -1: ok &= True
+#                else: ok &= False
             except Exception, e:
                 error(e)
                 ok &= False
@@ -393,7 +462,7 @@ class SFComm:
                 'sure': '1',
                 'submit': 'Send Notice'}
         
-        data = self.fetch_url(url, urlencode(form))
+        data = self.fetch_url(url, urlencode(form))[0]
         # notification status?!?!
         return data
 
@@ -411,9 +480,9 @@ class SFComm:
         ok = True
         for file_id in file_ids:
             form['file_id'] = file_id
-            data = self.fetch_url(url, urlencode(form))
-            if data.find("File Deleted") != -1: ok &= True
-            else: ok &= False
+            ok &= self.fetch_url(url, urlencode(form), ok_status="File Deleted")[1]
+#            if data.find("File Deleted") != -1: ok &= True
+#            else: ok &= False
         return ok
 
 
@@ -498,10 +567,10 @@ class SFComm:
         # replace each #0A in the message textarea with a newline
         encoded += '&details=%s' % escaped_message.replace("%0A", "\n")
 
-        data = self.fetch_url(url, encoded, mainMessageQueue)
-        
-        if data.find("News Added.") != -1: return 1
-        else: return 0
+        return self.fetch_url(url, encoded, mainMessageQueue, ok_status="News Added.")[1]
+                
+#        if data.find("News Added.") != -1: return 1
+#        else: return 0
 
 
 if __name__ == '__main__':
